@@ -693,12 +693,17 @@ class BaseDataset:
         ):
             data = [data]
         metadata = []
+        if not partition_by:
+            schema = self.metadata.schema.to_arrow_schema() if self.metadata else None
+        else:
+            schema = self.schema if self.schema else None
+
         for data_ in data:
             writer = Writer(
                 data=data_,
                 path=self._path,
                 filesystem=self._filesystem,
-                schema=self.schema if not alter_schema else None,
+                schema=schema if not alter_schema else None,
             )
             if writer.shape[0] == 0:
                 continue
@@ -708,12 +713,6 @@ class BaseDataset:
             if unique:
                 writer.unique(columns=unique)
 
-            if partition_by:
-                writer.add_datepart_columns(
-                    columns=partition_by,
-                    timestamp_column=self._timestamp_column,
-                )
-
             writer.cast_schema(
                 # use_large_string=use_large_string,
                 ts_unit=ts_unit,
@@ -722,6 +721,12 @@ class BaseDataset:
                 alter_schema=alter_schema,
             )
 
+            if partition_by:
+                writer.add_datepart_columns(
+                    columns=partition_by,
+                    timestamp_column=self._timestamp_column,
+                )
+
             if mode == "delta" and self.is_loaded:
                 writer._to_polars()
                 other_df = self._get_delta_other_df(
@@ -1043,8 +1048,12 @@ class ParquetDataset(PydalaDatasetMetadata, BaseDataset):
 
         if update_metadata:
             for md in metadata:
-                f = list(md.keys())[0].replace(self._path, "").lstrip("/")
                 metadata_ = list(md.values())[0]
+                if self.metadata is not None:
+                    if metadata_.schema != self.metadata.schema:
+                        continue
+
+                f = list(md.keys())[0].replace(self._path, "").lstrip("/")
                 metadata_.set_file_path(f)
                 if self._file_metadata is None:
                     self._file_metadata = {f: metadata_}
@@ -1282,7 +1291,7 @@ class Optimize(ParquetDataset):
         unique: bool = False,
         **kwargs,
     ):
-        filter_ = f"{timestamp_column} >= '{start_date}' AND {timestamp_column} < '{end_date}'"
+        filter_ = f"'{timestamp_column}'>= '{start_date}' AND {timestamp_column} < '{end_date}'"
 
         scan = self.scan(filter_)
         if len(self.scan_files) == 1:
